{#
# This file is part of Invenio.
# Copyright (C) 2015 CERN.
#
# Invenio is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
# MA 02111-1307, USA.
#
# In applying this license, CERN does not
# waive the privileges and immunities granted to it by virtue of its status
# as an Intergovernmental Organization or submit itself to any jurisdiction.
#}
<footer id="footer">
  <div class="container">
    <div class="row">
      <div class="col-sm-12 col-md-12" style="text-align: right;">
        <hr />
        <ul class="list-unstyled">
          {% if config.I18N_LANGUAGES %}
            {% from "invenio_i18n/macros/language_selector.html" import language_selector %}
            <li>
              {{ language_selector() }}
            </li>
          {% endif %}
          <li>
            {% trans link="http://inveniosoftware.org" %}Powered by <a href="{{link}}">Invenio</a>{% endtrans %}
          </li>
        </ul>
      </div>
    </div>
  </div>
</footer>
